@@ -57,27 +57,12 @@ class AyncExtractor:
 
     def _get_base_ex_req(self, response):
         base_ex_req = None
-        if response.request.meta.get("render_proxy.api", None) is None:
-            base_ex_req = {
-                "URL": response.url,
-                "Content": to_unicode(base64.encodebytes(response.body)),
-                "ContentType": to_unicode(response.headers.get("Content-Type")),
-            }
-        else:
-            render_body = json.loads(response.body.decode("utf8"))
-            if (
-                "renderStatus" in render_body
-                and render_body["renderStatus"] == "RENDER_OK"
-                and render_body["httpStatus"] < 300
-                and render_body["httpStatus"] >= 200
-            ):
-                base_ex_req = {
-                    "URL": render_body["url"],
-                    "Content": to_unicode(
-                        base64.encodebytes(render_body["renderPage"].encode("utf-8"))
-                    ),
-                    "ContentType": "html;charset=utf-8",
-                }
+        base_ex_req = {
+            "URL": response.url,
+            "Content": to_unicode(base64.encodebytes(response.body)),
+            # "Content": response.body.decode("utf8"),
+            "ContentType": "text/html; charset=utf-8",
+        }
         return base_ex_req
 
     async def _get_links(self, rules, response):
@@ -107,10 +92,17 @@ class AyncExtractor:
                 ):
                     ex_req[key_map[key]] = v
 
-            redirect_urls=response.request.meta.get("redirect_urls", None)
-            extractor_redirect_switch=response.request.meta.get("extractor.redirect.switch", False)
-            if ex_req[key_map["same_domain_only"]] and redirect_urls is not None and len(redirect_urls) > 0 and not extractor_redirect_switch:
-                root_host=parse_url(redirect_urls[0]).netloc.lower()
+            redirect_urls = response.request.meta.get("redirect_urls", None)
+            extractor_redirect_switch = response.request.meta.get(
+                "extractor.redirect.switch", False
+            )
+            if (
+                ex_req[key_map["same_domain_only"]]
+                and redirect_urls is not None
+                and len(redirect_urls) > 0
+                and not extractor_redirect_switch
+            ):
+                root_host = parse_url(redirect_urls[0]).netloc.lower()
                 if root_host and isinstance(ex_req[key_map["allow_domains"]], list):
                     ex_req[key_map["allow_domains"]].append(root_host)
                     ex_req[key_map["same_domain_only"]] = False
